@@ -91,7 +91,7 @@ def _case_insensitive_glob(s: str) -> str:
 def _first_file(setup_cfg: str, prefix: str) -> Optional[str]:
     prefix = _case_insensitive_glob(prefix)
     path = _adjacent_filename(setup_cfg, prefix)
-    for filename in glob.iglob(f'{path}*'):
+    for filename in sorted(glob.iglob(f'{path}*')):
         if os.path.isfile(filename):
             return filename
     else:
@@ -398,11 +398,11 @@ def format_file(
         if section not in cfg:
             continue
 
-        new_section = {
-            k: cfg[section].pop(k) for k in key_order if k in cfg[section]
-        }
+        entries = {k.replace('-', '_'): v for k, v in cfg[section].items()}
+
+        new_section = {k: entries.pop(k) for k in key_order if k in entries}
         # sort any remaining keys
-        new_section.update(sorted(cfg[section].items()))
+        new_section.update(sorted(entries.items()))
 
         sections[section] = new_section
         cfg.pop(section)
